@@ -1,6 +1,6 @@
 /* Dynamically allocated strings
 
-   Copyright (c) 2001-2005, 2008-2011 Free Software Foundation, Inc.
+   Copyright (c) 2001-2014 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -58,8 +58,8 @@ astr_new (void)
   return as;
 }
 
-castr
-castr_new_nstr (const char *s, size_t n)
+const_astr
+const_astr_new_nstr (const char *s, size_t n)
 {
   astr as;
   as = (astr) XZALLOC (struct astr);
@@ -69,13 +69,13 @@ castr_new_nstr (const char *s, size_t n)
 }
 
 const char *
-astr_cstr (castr as)
+astr_cstr (const_astr as)
 {
   return (const char *) (as->text);
 }
 
 size_t
-astr_len (castr as)
+astr_len (const_astr as)
 {
   return as->len;
 }
@@ -162,7 +162,7 @@ astr_set (astr as, size_t pos, int c, size_t n)
  */
 
 char
-astr_get (castr as, size_t pos)
+astr_get (const_astr as, size_t pos)
 {
   assert (pos <= astr_len (as));
   return (astr_cstr (as))[pos];
@@ -182,7 +182,7 @@ astr_new_cstr (const char *s)
 }
 
 astr
-astr_cpy (astr as, castr src)
+astr_cpy (astr as, const_astr src)
 {
   return astr_ncpy_cstr (as, astr_cstr (src), astr_len (src));
 }
@@ -194,7 +194,7 @@ astr_cpy_cstr (astr as, const char *s)
 }
 
 astr
-astr_cat (astr as, castr src)
+astr_cat (astr as, const_astr src)
 {
   return astr_cat_nstr (as, astr_cstr (src), astr_len (src));
 }
@@ -213,7 +213,7 @@ astr_cat_char (astr as, int c)
 }
 
 astr
-astr_substr (castr as, size_t pos, size_t size)
+astr_substr (const_astr as, size_t pos, size_t size)
 {
   assert (pos + size <= astr_len (as));
   return astr_cat_nstr (astr_new (), astr_cstr (as) + pos, size);
@@ -263,7 +263,7 @@ astr_fmt (const char *fmt, ...)
 }
 
 astr
-astr_recase (astr as, enum casing newcase)
+astr_recase (astr as, casing newcase)
 {
   astr bs = astr_new ();
 
@@ -281,8 +281,6 @@ astr_recase (astr as, enum casing newcase)
 
 #ifdef TEST
 
-#include <config.h>
-
 #include <stdio.h>
 #include "progname.h"
 
@@ -298,21 +296,13 @@ assert_eq (astr as, const char *s)
     }
 }
 
-/* Stub to make xalloc_die happy. */
-void zile_exit (int doabort);
-
-_Noreturn void
-zile_exit (int doabort _GL_UNUSED_PARAMETER)
-{
-  exit (EXIT_CRASH);
-}
-
-
 int
 main (int argc _GL_UNUSED_PARAMETER, char **argv)
 {
   astr as1, as2, as3;
 
+  GC_init ();
+
   set_program_name (argv[0]);
 
   as1 = astr_new ();
