@@ -1,6 +1,6 @@
 /* Main types and definitions
 
-   Copyright (c) 1997-2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2014 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -22,8 +22,6 @@
 #ifndef ZILE_H
 #define ZILE_H
 
-#include <config.h>
-
 #include <stdlib.h>
 #include <stdbool.h>
 #include <limits.h>
@@ -53,31 +51,23 @@
  *--------------------------------------------------------------------------*/
 
 /* Opaque types. */
-typedef struct Marker Marker;
-typedef struct History History;
-typedef struct Undo Undo;
-typedef struct Macro Macro;
+typedef struct Region *Region;
+typedef struct Marker *Marker;
+typedef struct History *History;
+typedef struct Undo *Undo;
+typedef struct Macro *Macro;
 typedef struct Binding *Binding;
-typedef struct Buffer Buffer;
-typedef struct Window Window;
-typedef struct Completion Completion;
+typedef struct Buffer *Buffer;
+typedef struct Window *Window;
+typedef struct Completion *Completion;
 
-/* FIXME: Types which should really be opaque. */
-typedef struct Region Region;
-
-struct Region
+typedef enum
 {
-  size_t start;		/* The region start. */
-  size_t end;		/* The region end. */
-};
-
-enum
-{
-  COMPLETION_NOTMATCHED,
-  COMPLETION_MATCHED,
-  COMPLETION_MATCHEDNONUNIQUE,
-  COMPLETION_NONUNIQUE
-};
+  completion_notmatched,
+  completion_matched,
+  completion_matchednonunique,
+  completion_nonunique,
+} completion_code;
 
 /* Completion flags */
 #define CFLAG_POPPEDUP	0000001	/* Completion window has been popped up. */
@@ -90,21 +80,21 @@ enum
 
 #define GETTER(Obj, name, ty, field)            \
   _GL_ATTRIBUTE_PURE ty                         \
-  get_ ## name ## _ ## field (const Obj *p)     \
+  get_ ## name ## _ ## field (const Obj p)      \
   {                                             \
     return p->field;                            \
   }                                             \
 
 #define SETTER(Obj, name, ty, field)            \
   void                                          \
-  set_ ## name ## _ ## field (Obj *p, ty field) \
+  set_ ## name ## _ ## field (Obj p, ty field)  \
   {                                             \
     p->field = field;                           \
   }
 
 #define STR_SETTER(Obj, name, field)                            \
   void                                                          \
-  set_ ## name ## _ ## field (Obj *p, const char *field)        \
+  set_ ## name ## _ ## field (Obj p, const char *field)         \
   {                                                             \
     p->field = field ? xstrdup (field) : NULL;                  \
   }
@@ -143,7 +133,7 @@ typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
 
 /* String argument. */
 #define STR_ARG(name)                           \
-  castr name = NULL;
+  const_astr name = NULL;
 #define STR_INIT(name)                                  \
   if (arglist && arglist->next)                         \
     {                                                   \
@@ -169,7 +159,7 @@ typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
 /* Integer argument which can either be argument or uniarg. */
 #define INT_OR_UNIARG(name) \
   long name = 1;            \
-  bool noarg = false;
+  _GL_UNUSED bool noarg = false;
 #define INT_OR_UNIARG_INIT(name)                             \
   INT_INIT (name)                                            \
   else                                                       \
