@@ -1,6 +1,6 @@
 /* Marker fields
 
-   Copyright (c) 2009, 2011 Free Software Foundation, Inc.
+   Copyright (c) 2009-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,6 +19,6 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-FIELD(Marker *, next)		/* Used to chain all markers in the buffer. */
+FIELD(Marker, next)		/* Used to chain all markers in the buffer. */
 FIELD(size_t, o)		/* Marker offset within buffer. */
-FIELD(Buffer *, bp)		/* Buffer that marker points into. */
+FIELD(Buffer, bp)		/* Buffer that marker points into. */
