@@ -1,6 +1,6 @@
 /* Minibuffer facility functions
 
-   Copyright (c) 1997-2004, 2008-2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2014 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -29,7 +29,7 @@
 #include "main.h"
 #include "extern.h"
 
-static History *files_history = NULL;
+static History files_history = NULL;
 static char *minibuf_contents = NULL;
 
 /*--------------------------------------------------------------------------
@@ -42,7 +42,7 @@ init_minibuf (void)
   files_history = history_new ();
 }
 
-int
+bool
 minibuf_no_error (void)
 {
   return minibuf_contents == NULL;
@@ -62,7 +62,7 @@ minibuf_refresh (void)
     }
 }
 
-static void
+_GL_ATTRIBUTE_FORMAT_PRINTF(1, 0) static void
 minibuf_vwrite (const char *fmt, va_list ap)
 {
   char *s = xvasprintf (fmt, ap);
@@ -104,7 +104,7 @@ minibuf_error (const char *fmt, ...)
 /*
  * Read a string from the minibuffer.
  */
-castr
+const_astr
 minibuf_read (const char *fmt, const char *value, ...)
 {
   va_list ap;
@@ -133,7 +133,7 @@ minibuf_read_number (const char *fmt, ...)
 
   do
     {
-      castr as = minibuf_read (buf, "");
+      const_astr as = minibuf_read ("%s", "", buf);
       if (as == NULL || astr_cstr (as) == NULL)
         {
           n = LONG_MAX;
@@ -158,11 +158,11 @@ minibuf_read_number (const char *fmt, ...)
 /*
  * Read a filename from the minibuffer.
  */
-castr
+const_astr
 minibuf_read_filename (const char *fmt, const char *value,
                        const char *file, ...)
 {
-  castr p = NULL;
+  const_astr p = NULL;
 
   astr as = astr_new_cstr (value);
   if (file == NULL && astr_len (as) > 0 && astr_get (as, astr_len (as) - 1) != '/')
@@ -177,7 +177,7 @@ minibuf_read_filename (const char *fmt, const char *value,
 
       as = compact_path (as);
 
-      Completion *cp = completion_new (true);
+      Completion cp = completion_new (true);
       size_t pos = astr_len (as);
       if (file)
         pos -= strlen (file);
@@ -203,56 +203,20 @@ minibuf_test_in_completions (const char *ms, gl_list_t completions)
   return gl_sortedlist_search (completions, completion_strcmp, ms) != NULL;
 }
 
-int
-minibuf_read_yn (const char *fmt, ...)
-{
-  va_list ap;
-  char *buf;
-  const char *errmsg = "";
-  int ret;
-
-  va_start (ap, fmt);
-  buf = xvasprintf (fmt, ap);
-  va_end (ap);
-
-  for (ret = -2; ret == -2;) {
-    size_t key;
-
-    minibuf_write ("%s%s", errmsg, buf);
-    key = getkeystroke (GETKEY_DEFAULT);
-    switch (key)
-      {
-      case 'y':
-        ret = true;
-        break;
-      case 'n':
-        ret = false;
-        break;
-      case KBD_CTRL | 'g':
-        ret = -1;
-        break;
-      default:
-        errmsg = "Please answer y or n.  ";
-      }
-  }
-
-  return ret;
-}
-
 int
 minibuf_read_yesno (const char *fmt, ...)
 {
   va_list ap;
   const char *errmsg = "Please answer yes or no.";
-  Completion *cp = completion_new (false);
+  Completion cp = completion_new (false);
   int ret = -1;
 
   gl_sortedlist_add (get_completion_completions (cp), completion_strcmp, xstrdup ("yes"));
   gl_sortedlist_add (get_completion_completions (cp), completion_strcmp, xstrdup ("no"));
 
   va_start (ap, fmt);
-  castr ms = minibuf_vread_completion (fmt, "", cp, NULL, errmsg,
-                                       minibuf_test_in_completions, errmsg, ap);
+  const_astr ms = minibuf_vread_completion (fmt, "", cp, NULL, errmsg,
+                                            minibuf_test_in_completions, errmsg, ap);
   va_end (ap);
 
   if (ms != NULL)
@@ -267,9 +231,8 @@ minibuf_read_yesno (const char *fmt, ...)
   return ret;
 }
 
-castr
-minibuf_read_completion (const char *fmt, const char *value, Completion * cp,
-                         History * hp, ...)
+const_astr
+minibuf_read_completion (const char *fmt, const char *value, Completion cp, History hp, ...)
 {
   va_list ap;
   char *buf;
@@ -284,13 +247,13 @@ minibuf_read_completion (const char *fmt, const char *value, Completion * cp,
 /*
  * Read a string from the minibuffer using a completion.
  */
-castr
-minibuf_vread_completion (const char *fmt, const char *value, Completion * cp,
-                          History * hp, const char *empty_err,
+const_astr
+minibuf_vread_completion (const char *fmt, const char *value, Completion cp,
+                          History hp, const char *empty_err,
                           bool (*test) (const char *s, gl_list_t completions),
                           const char *invalid_err, va_list ap)
 {
-  castr ms;
+  const_astr ms;
   char *buf = xvasprintf (fmt, ap);
 
   for (;;)
@@ -304,7 +267,7 @@ minibuf_vread_completion (const char *fmt, const char *value, Completion * cp,
         }
       else if (astr_len (ms) == 0)
         {
-          minibuf_error (empty_err);
+          minibuf_error ("%s", empty_err);
           ms = NULL;
           break;
         }
@@ -312,7 +275,7 @@ minibuf_vread_completion (const char *fmt, const char *value, Completion * cp,
         {
           astr as = astr_cpy (astr_new (), ms);
           /* Complete partial words if possible. */
-          if (completion_try (cp, as, false) == COMPLETION_MATCHED)
+          if (completion_try (cp, as, false) == completion_matched)
             ms = astr_new_cstr (get_completion_match (cp));
 
           if (test (astr_cstr (ms), get_completion_completions (cp)))
@@ -324,7 +287,10 @@ minibuf_vread_completion (const char *fmt, const char *value, Completion * cp,
             }
           else
             {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
               minibuf_error (invalid_err, astr_cstr (ms));
+#pragma GCC diagnostic pop
               waitkey ();
             }
         }
